# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: container.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import aiddl_pb2 as aiddl__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63ontainer.proto\x12\x17org.aiddl.external.grpc\x1a\x0b\x61iddl.proto\"W\n\x13\x46unctionCallRequest\x12\x14\n\x0c\x66unction_uri\x18\x01 \x01(\t\x12*\n\x03\x61rg\x18\x02 \x01(\x0b\x32\x1d.org.aiddl.external.grpc.Term\"z\n\x12\x46unctionCallResult\x12\x35\n\x06status\x18\x01 \x01(\x0e\x32%.org.aiddl.external.grpc.ResultStatus\x12-\n\x06result\x18\x02 \x01(\x0b\x32\x1d.org.aiddl.external.grpc.Term*7\n\x0cResultStatus\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\r\n\tEXCEPTION\x10\x02\x32v\n\tContainer\x12i\n\x0c\x46unctionCall\x12,.org.aiddl.external.grpc.FunctionCallRequest\x1a+.org.aiddl.external.grpc.FunctionCallResultB\x19\n\x17org.aiddl.external.grpcb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'container_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027org.aiddl.external.grpc'
  _RESULTSTATUS._serialized_start=270
  _RESULTSTATUS._serialized_end=325
  _FUNCTIONCALLREQUEST._serialized_start=57
  _FUNCTIONCALLREQUEST._serialized_end=144
  _FUNCTIONCALLRESULT._serialized_start=146
  _FUNCTIONCALLRESULT._serialized_end=268
  _CONTAINER._serialized_start=327
  _CONTAINER._serialized_end=445
# @@protoc_insertion_point(module_scope)
